==> g2o-python-0.0.3.tar.gz: g2o-python-0.0.3/_skbuild/linux-x86_64-3.10/cmake-install/lib/cmake/g2o/g2oTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "g2o::stuff" for configuration "Release"
set_property(TARGET g2o::stuff APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(g2o::stuff PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "C;CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libg2o_stuff.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS g2o::stuff )
list(APPEND _IMPORT_CHECK_FILES_FOR_g2o::stuff "${_IMPORT_PREFIX}/lib/libg2o_stuff.a" )

# Import target "g2o::core" for configuration "Release"
set_property(TARGET g2o::core APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(g2o::core PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libg2o_core.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS g2o::core )
list(APPEND _IMPORT_CHECK_FILES_FOR_g2o::core "${_IMPORT_PREFIX}/lib/libg2o_core.a" )

# Import target "g2o::types_slam2d" for configuration "Release"
set_property(TARGET g2o::types_slam2d APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(g2o::types_slam2d PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libg2o_types_slam2d.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS g2o::types_slam2d )
list(APPEND _IMPORT_CHECK_FILES_FOR_g2o::types_slam2d "${_IMPORT_PREFIX}/lib/libg2o_types_slam2d.a" )

# Import target "g2o::types_slam2d_addons" for configuration "Release"
set_property(TARGET g2o::types_slam2d_addons APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(g2o::types_slam2d_addons PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libg2o_types_slam2d_addons.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS g2o::types_slam2d_addons )
list(APPEND _IMPORT_CHECK_FILES_FOR_g2o::types_slam2d_addons "${_IMPORT_PREFIX}/lib/libg2o_types_slam2d_addons.a" )

# Import target "g2o::types_data" for configuration "Release"
set_property(TARGET g2o::types_data APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(g2o::types_data PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libg2o_types_data.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS g2o::types_data )
list(APPEND _IMPORT_CHECK_FILES_FOR_g2o::types_data "${_IMPORT_PREFIX}/lib/libg2o_types_data.a" )

# Import target "g2o::types_sclam2d" for configuration "Release"
set_property(TARGET g2o::types_sclam2d APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(g2o::types_sclam2d PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libg2o_types_sclam2d.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS g2o::types_sclam2d )
list(APPEND _IMPORT_CHECK_FILES_FOR_g2o::types_sclam2d "${_IMPORT_PREFIX}/lib/libg2o_types_sclam2d.a" )

# Import target "g2o::types_slam3d" for configuration "Release"
set_property(TARGET g2o::types_slam3d APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(g2o::types_slam3d PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libg2o_types_slam3d.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS g2o::types_slam3d )
list(APPEND _IMPORT_CHECK_FILES_FOR_g2o::types_slam3d "${_IMPORT_PREFIX}/lib/libg2o_types_slam3d.a" )

# Import target "g2o::types_slam3d_addons" for configuration "Release"
set_property(TARGET g2o::types_slam3d_addons APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(g2o::types_slam3d_addons PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libg2o_types_slam3d_addons.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS g2o::types_slam3d_addons )
list(APPEND _IMPORT_CHECK_FILES_FOR_g2o::types_slam3d_addons "${_IMPORT_PREFIX}/lib/libg2o_types_slam3d_addons.a" )

# Import target "g2o::types_sba" for configuration "Release"
set_property(TARGET g2o::types_sba APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(g2o::types_sba PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libg2o_types_sba.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS g2o::types_sba )
list(APPEND _IMPORT_CHECK_FILES_FOR_g2o::types_sba "${_IMPORT_PREFIX}/lib/libg2o_types_sba.a" )

# Import target "g2o::types_icp" for configuration "Release"
set_property(TARGET g2o::types_icp APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(g2o::types_icp PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libg2o_types_icp.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS g2o::types_icp )
list(APPEND _IMPORT_CHECK_FILES_FOR_g2o::types_icp "${_IMPORT_PREFIX}/lib/libg2o_types_icp.a" )

# Import target "g2o::types_sim3" for configuration "Release"
set_property(TARGET g2o::types_sim3 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(g2o::types_sim3 PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libg2o_types_sim3.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS g2o::types_sim3 )
list(APPEND _IMPORT_CHECK_FILES_FOR_g2o::types_sim3 "${_IMPORT_PREFIX}/lib/libg2o_types_sim3.a" )

# Import target "g2o::solver_pcg" for configuration "Release"
set_property(TARGET g2o::solver_pcg APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(g2o::solver_pcg PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libg2o_solver_pcg.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS g2o::solver_pcg )
list(APPEND _IMPORT_CHECK_FILES_FOR_g2o::solver_pcg "${_IMPORT_PREFIX}/lib/libg2o_solver_pcg.a" )

# Import target "g2o::solver_dense" for configuration "Release"
set_property(TARGET g2o::solver_dense APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(g2o::solver_dense PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libg2o_solver_dense.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS g2o::solver_dense )
list(APPEND _IMPORT_CHECK_FILES_FOR_g2o::solver_dense "${_IMPORT_PREFIX}/lib/libg2o_solver_dense.a" )

# Import target "g2o::solver_slam2d_linear" for configuration "Release"
set_property(TARGET g2o::solver_slam2d_linear APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(g2o::solver_slam2d_linear PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libg2o_solver_slam2d_linear.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS g2o::solver_slam2d_linear )
list(APPEND _IMPORT_CHECK_FILES_FOR_g2o::solver_slam2d_linear "${_IMPORT_PREFIX}/lib/libg2o_solver_slam2d_linear.a" )

# Import target "g2o::solver_structure_only" for configuration "Release"
set_property(TARGET g2o::solver_structure_only APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(g2o::solver_structure_only PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libg2o_solver_structure_only.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS g2o::solver_structure_only )
list(APPEND _IMPORT_CHECK_FILES_FOR_g2o::solver_structure_only "${_IMPORT_PREFIX}/lib/libg2o_solver_structure_only.a" )

# Import target "g2o::solver_csparse" for configuration "Release"
set_property(TARGET g2o::solver_csparse APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(g2o::solver_csparse PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libg2o_solver_csparse.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS g2o::solver_csparse )
list(APPEND _IMPORT_CHECK_FILES_FOR_g2o::solver_csparse "${_IMPORT_PREFIX}/lib/libg2o_solver_csparse.a" )

# Import target "g2o::csparse_extension" for configuration "Release"
set_property(TARGET g2o::csparse_extension APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(g2o::csparse_extension PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libg2o_csparse_extension.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS g2o::csparse_extension )
list(APPEND _IMPORT_CHECK_FILES_FOR_g2o::csparse_extension "${_IMPORT_PREFIX}/lib/libg2o_csparse_extension.a" )

# Import target "g2o::solver_cholmod" for configuration "Release"
set_property(TARGET g2o::solver_cholmod APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(g2o::solver_cholmod PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libg2o_solver_cholmod.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS g2o::solver_cholmod )
list(APPEND _IMPORT_CHECK_FILES_FOR_g2o::solver_cholmod "${_IMPORT_PREFIX}/lib/libg2o_solver_cholmod.a" )

# Import target "g2o::solver_eigen" for configuration "Release"
set_property(TARGET g2o::solver_eigen APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(g2o::solver_eigen PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libg2o_solver_eigen.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS g2o::solver_eigen )
list(APPEND _IMPORT_CHECK_FILES_FOR_g2o::solver_eigen "${_IMPORT_PREFIX}/lib/libg2o_solver_eigen.a" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> g2o-python-0.0.9.tar.gz: g2o-python-0.0.9/_skbuild/linux-x86_64-3.10/cmake-install/lib/cmake/g2o/g2oTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "g2o::stuff" for configuration "Release"
set_property(TARGET g2o::stuff APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(g2o::stuff PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "C;CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libg2o_stuff.a"
  )

list(APPEND _cmake_import_check_targets g2o::stuff )
list(APPEND _cmake_import_check_files_for_g2o::stuff "${_IMPORT_PREFIX}/lib/libg2o_stuff.a" )

# Import target "g2o::core" for configuration "Release"
set_property(TARGET g2o::core APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(g2o::core PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libg2o_core.a"
  )

list(APPEND _cmake_import_check_targets g2o::core )
list(APPEND _cmake_import_check_files_for_g2o::core "${_IMPORT_PREFIX}/lib/libg2o_core.a" )

# Import target "g2o::types_slam2d" for configuration "Release"
set_property(TARGET g2o::types_slam2d APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(g2o::types_slam2d PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libg2o_types_slam2d.a"
  )

list(APPEND _cmake_import_check_targets g2o::types_slam2d )
list(APPEND _cmake_import_check_files_for_g2o::types_slam2d "${_IMPORT_PREFIX}/lib/libg2o_types_slam2d.a" )

# Import target "g2o::types_slam2d_addons" for configuration "Release"
set_property(TARGET g2o::types_slam2d_addons APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(g2o::types_slam2d_addons PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libg2o_types_slam2d_addons.a"
  )

list(APPEND _cmake_import_check_targets g2o::types_slam2d_addons )
list(APPEND _cmake_import_check_files_for_g2o::types_slam2d_addons "${_IMPORT_PREFIX}/lib/libg2o_types_slam2d_addons.a" )

# Import target "g2o::types_data" for configuration "Release"
set_property(TARGET g2o::types_data APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(g2o::types_data PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libg2o_types_data.a"
  )

list(APPEND _cmake_import_check_targets g2o::types_data )
list(APPEND _cmake_import_check_files_for_g2o::types_data "${_IMPORT_PREFIX}/lib/libg2o_types_data.a" )

# Import target "g2o::types_sclam2d" for configuration "Release"
set_property(TARGET g2o::types_sclam2d APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(g2o::types_sclam2d PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libg2o_types_sclam2d.a"
  )

list(APPEND _cmake_import_check_targets g2o::types_sclam2d )
list(APPEND _cmake_import_check_files_for_g2o::types_sclam2d "${_IMPORT_PREFIX}/lib/libg2o_types_sclam2d.a" )

# Import target "g2o::types_slam3d" for configuration "Release"
set_property(TARGET g2o::types_slam3d APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(g2o::types_slam3d PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libg2o_types_slam3d.a"
  )

list(APPEND _cmake_import_check_targets g2o::types_slam3d )
list(APPEND _cmake_import_check_files_for_g2o::types_slam3d "${_IMPORT_PREFIX}/lib/libg2o_types_slam3d.a" )

# Import target "g2o::types_slam3d_addons" for configuration "Release"
set_property(TARGET g2o::types_slam3d_addons APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(g2o::types_slam3d_addons PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libg2o_types_slam3d_addons.a"
  )

list(APPEND _cmake_import_check_targets g2o::types_slam3d_addons )
list(APPEND _cmake_import_check_files_for_g2o::types_slam3d_addons "${_IMPORT_PREFIX}/lib/libg2o_types_slam3d_addons.a" )

# Import target "g2o::types_sba" for configuration "Release"
set_property(TARGET g2o::types_sba APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(g2o::types_sba PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libg2o_types_sba.a"
  )

list(APPEND _cmake_import_check_targets g2o::types_sba )
list(APPEND _cmake_import_check_files_for_g2o::types_sba "${_IMPORT_PREFIX}/lib/libg2o_types_sba.a" )

# Import target "g2o::types_icp" for configuration "Release"
set_property(TARGET g2o::types_icp APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(g2o::types_icp PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libg2o_types_icp.a"
  )

list(APPEND _cmake_import_check_targets g2o::types_icp )
list(APPEND _cmake_import_check_files_for_g2o::types_icp "${_IMPORT_PREFIX}/lib/libg2o_types_icp.a" )

# Import target "g2o::types_sim3" for configuration "Release"
set_property(TARGET g2o::types_sim3 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(g2o::types_sim3 PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libg2o_types_sim3.a"
  )

list(APPEND _cmake_import_check_targets g2o::types_sim3 )
list(APPEND _cmake_import_check_files_for_g2o::types_sim3 "${_IMPORT_PREFIX}/lib/libg2o_types_sim3.a" )

# Import target "g2o::solver_pcg" for configuration "Release"
set_property(TARGET g2o::solver_pcg APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(g2o::solver_pcg PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libg2o_solver_pcg.a"
  )

list(APPEND _cmake_import_check_targets g2o::solver_pcg )
list(APPEND _cmake_import_check_files_for_g2o::solver_pcg "${_IMPORT_PREFIX}/lib/libg2o_solver_pcg.a" )

# Import target "g2o::solver_dense" for configuration "Release"
set_property(TARGET g2o::solver_dense APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(g2o::solver_dense PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libg2o_solver_dense.a"
  )

list(APPEND _cmake_import_check_targets g2o::solver_dense )
list(APPEND _cmake_import_check_files_for_g2o::solver_dense "${_IMPORT_PREFIX}/lib/libg2o_solver_dense.a" )

# Import target "g2o::solver_slam2d_linear" for configuration "Release"
set_property(TARGET g2o::solver_slam2d_linear APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(g2o::solver_slam2d_linear PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libg2o_solver_slam2d_linear.a"
  )

list(APPEND _cmake_import_check_targets g2o::solver_slam2d_linear )
list(APPEND _cmake_import_check_files_for_g2o::solver_slam2d_linear "${_IMPORT_PREFIX}/lib/libg2o_solver_slam2d_linear.a" )

# Import target "g2o::solver_structure_only" for configuration "Release"
set_property(TARGET g2o::solver_structure_only APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(g2o::solver_structure_only PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libg2o_solver_structure_only.a"
  )

list(APPEND _cmake_import_check_targets g2o::solver_structure_only )
list(APPEND _cmake_import_check_files_for_g2o::solver_structure_only "${_IMPORT_PREFIX}/lib/libg2o_solver_structure_only.a" )

# Import target "g2o::solver_csparse" for configuration "Release"
set_property(TARGET g2o::solver_csparse APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(g2o::solver_csparse PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libg2o_solver_csparse.a"
  )

list(APPEND _cmake_import_check_targets g2o::solver_csparse )
list(APPEND _cmake_import_check_files_for_g2o::solver_csparse "${_IMPORT_PREFIX}/lib/libg2o_solver_csparse.a" )

# Import target "g2o::csparse_extension" for configuration "Release"
set_property(TARGET g2o::csparse_extension APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(g2o::csparse_extension PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libg2o_csparse_extension.a"
  )

list(APPEND _cmake_import_check_targets g2o::csparse_extension )
list(APPEND _cmake_import_check_files_for_g2o::csparse_extension "${_IMPORT_PREFIX}/lib/libg2o_csparse_extension.a" )

# Import target "g2o::solver_cholmod" for configuration "Release"
set_property(TARGET g2o::solver_cholmod APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(g2o::solver_cholmod PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libg2o_solver_cholmod.a"
  )

list(APPEND _cmake_import_check_targets g2o::solver_cholmod )
list(APPEND _cmake_import_check_files_for_g2o::solver_cholmod "${_IMPORT_PREFIX}/lib/libg2o_solver_cholmod.a" )

# Import target "g2o::solver_eigen" for configuration "Release"
set_property(TARGET g2o::solver_eigen APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(g2o::solver_eigen PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libg2o_solver_eigen.a"
  )

list(APPEND _cmake_import_check_targets g2o::solver_eigen )
list(APPEND _cmake_import_check_files_for_g2o::solver_eigen "${_IMPORT_PREFIX}/lib/libg2o_solver_eigen.a" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
